/*
  PDD layer implementation for peripheral type PIT
  (C) 2010 Freescale, Inc. All rights reserved.

  This file is static and it is generated from API-Factory
*/

#if !defined(PIT_PDD_H_)
#define PIT_PDD_H_

/* ----------------------------------------------------------------------------
   -- Test if supported MCU is active
   ---------------------------------------------------------------------------- */

#if !defined(MCU_ACTIVE)
  // No MCU is active
  #error PIT PDD library: No derivative is active. Place proper #include with PDD memory map before including PDD library.
#elif \
      !defined(MCU_MK10D10) /* PIT */ && \
      !defined(MCU_MK10D5) /* PIT */ && \
      !defined(MCU_MK10D7) /* PIT */ && \
      !defined(MCU_MK10F12) /* PIT */ && \
      !defined(MCU_MK10DZ10) /* PIT */ && \
      !defined(MCU_MK11D5) /* PIT */ && \
      !defined(MCU_MK12D5) /* PIT */ && \
      !defined(MCU_MK20D10) /* PIT */ && \
      !defined(MCU_MK20D5) /* PIT */ && \
      !defined(MCU_MK20D7) /* PIT */ && \
      !defined(MCU_MK20F12) /* PIT */ && \
      !defined(MCU_MK20DZ10) /* PIT */ && \
      !defined(MCU_MK21D5) /* PIT */ && \
      !defined(MCU_MK22D5) /* PIT */ && \
      !defined(MCU_MK30D10) /* PIT */ && \
      !defined(MCU_MK30D7) /* PIT */ && \
      !defined(MCU_MK30DZ10) /* PIT */ && \
      !defined(MCU_MK40D10) /* PIT */ && \
      !defined(MCU_MK40D7) /* PIT */ && \
      !defined(MCU_MK40DZ10) /* PIT */ && \
      !defined(MCU_MK40X256VMD100) /* PIT */ && \
      !defined(MCU_MK50D10) /* PIT */ && \
      !defined(MCU_MK50D7) /* PIT */ && \
      !defined(MCU_MK50DZ10) /* PIT */ && \
      !defined(MCU_MK51D10) /* PIT */ && \
      !defined(MCU_MK51D7) /* PIT */ && \
      !defined(MCU_MK51DZ10) /* PIT */ && \
      !defined(MCU_MK52D10) /* PIT */ && \
      !defined(MCU_MK52DZ10) /* PIT */ && \
      !defined(MCU_MK53D10) /* PIT */ && \
      !defined(MCU_MK53DZ10) /* PIT */ && \
      !defined(MCU_MK60D10) /* PIT */ && \
      !defined(MCU_MK60F12) /* PIT */ && \
      !defined(MCU_MK60F15) /* PIT */ && \
      !defined(MCU_MK60DZ10) /* PIT */ && \
      !defined(MCU_MK60N512VMD100) /* PIT */ && \
      !defined(MCU_MK61F12) /* PIT */ && \
      !defined(MCU_MK61F15) /* PIT */ && \
      !defined(MCU_MK70F12) /* PIT */ && \
      !defined(MCU_MK70F15) /* PIT */ && \
      !defined(MCU_MKL04Z4) /* PIT */ && \
      !defined(MCU_MKL05Z4) /* PIT */ && \
      !defined(MCU_MKL14Z4) /* PIT */ && \
      !defined(MCU_MKL15Z4) /* PIT */ && \
      !defined(MCU_MKL24Z4) /* PIT */ && \
      !defined(MCU_MKL25Z4) /* PIT */ && \
      !defined(MCU_PCK20L4) /* PIT */
  // Unsupported MCU is active
  #error PIT PDD library: Unsupported derivative is active.
#endif

#include "PDD_Types.h"

/* ----------------------------------------------------------------------------
   -- Method symbol definitions
   ---------------------------------------------------------------------------- */

/* PIT channel constants */
#define PIT_PDD_CHANNEL_0 0U                     /**< 0 */
#define PIT_PDD_CHANNEL_1 0x1U                   /**< 1 */
#define PIT_PDD_CHANNEL_2 0x2U                   /**< 2 */
#define PIT_PDD_CHANNEL_3 0x3U                   /**< 3 */

/* Module clock constants */
#define PIT_PDD_CLOCK_ENABLED 0U                 /**< Enabled */
#define PIT_PDD_CLOCK_DISABLED PIT_MCR_MDIS_MASK /**< Disabled */

/* Freeze constants */
#define PIT_PDD_TIMERS_RUN 0U                    /**< Run */
#define PIT_PDD_TIMERS_STOPPED PIT_MCR_FRZ_MASK  /**< Stopped */


/* ----------------------------------------------------------------------------
   -- GetInterruptMask
   ---------------------------------------------------------------------------- */

/**
 * Returns interrupt mask.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_GetInterruptMask(peripheralBase, ChannelIdx) ( \
    (uint32_t)(PIT_TCTRL_REG(peripheralBase,(ChannelIdx)) & PIT_TCTRL_TIE_MASK) \
  )

/* ----------------------------------------------------------------------------
   -- GetInterruptFlag
   ---------------------------------------------------------------------------- */

/**
 * Returns interrupt flag bit.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_GetInterruptFlag(peripheralBase, ChannelIdx) ( \
    (uint32_t)(PIT_TFLG_REG(peripheralBase,(ChannelIdx)) & PIT_TFLG_TIF_MASK) \
  )

/* ----------------------------------------------------------------------------
   -- EnableInterrupt
   ---------------------------------------------------------------------------- */

/**
 * Enables the PIT interrupt.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_EnableInterrupt(peripheralBase, ChannelIdx) ( \
    PIT_TCTRL_REG(peripheralBase,(ChannelIdx)) |= \
     PIT_TCTRL_TIE_MASK \
  )

/* ----------------------------------------------------------------------------
   -- DisableInterrupt
   ---------------------------------------------------------------------------- */

/**
 * Disables the PIT interrupt.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_DisableInterrupt(peripheralBase, ChannelIdx) ( \
    PIT_TCTRL_REG(peripheralBase,(ChannelIdx)) &= \
     (uint32_t)(~(uint32_t)PIT_TCTRL_TIE_MASK) \
  )

/* ----------------------------------------------------------------------------
   -- ClearInterruptFlag
   ---------------------------------------------------------------------------- */

/**
 * Clears PIT interrupt flag.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_ClearInterruptFlag(peripheralBase, ChannelIdx) ( \
    (PIT_TFLG_REG(peripheralBase,(ChannelIdx)) = \
     PIT_TFLG_TIF_MASK), \
    (void)PIT_LDVAL_REG(peripheralBase,(ChannelIdx)) \
  )

/* ----------------------------------------------------------------------------
   -- ModuleClock
   ---------------------------------------------------------------------------- */

/**
 * Enables/disables PIT module clock.
 * @param peripheralBase Peripheral base address.
 * @param Clock New value of the clock.
 */
#define PIT_PDD_ModuleClock(peripheralBase, Clock) ( \
    PIT_MCR_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(PIT_MCR_REG(peripheralBase) & (uint32_t)(~(uint32_t)PIT_MCR_MDIS_MASK))) | ( \
      (uint32_t)(Clock))) \
  )

/* ----------------------------------------------------------------------------
   -- ModuleFreeze
   ---------------------------------------------------------------------------- */

/**
 * Allows the timers to be stopped when the device enters debug mode.
 * @param peripheralBase Peripheral base address.
 * @param Freeze New value of the freeze.
 */
#define PIT_PDD_ModuleFreeze(peripheralBase, Freeze) ( \
    PIT_MCR_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(PIT_MCR_REG(peripheralBase) & (uint32_t)(~(uint32_t)PIT_MCR_FRZ_MASK))) | ( \
      (uint32_t)(Freeze))) \
  )

/* ----------------------------------------------------------------------------
   -- WriteLoadReg
   ---------------------------------------------------------------------------- */

/**
 * Writes value to the load register.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 * @param Value New content of the load register.
 */
#define PIT_PDD_WriteLoadReg(peripheralBase, ChannelIdx, Value) ( \
    PIT_LDVAL_REG(peripheralBase,(ChannelIdx)) = \
     (uint32_t)(Value) \
  )

/* ----------------------------------------------------------------------------
   -- ReadLoadReg
   ---------------------------------------------------------------------------- */

/**
 * Returns the content of the load register.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_ReadLoadReg(peripheralBase, ChannelIdx) ( \
    PIT_LDVAL_REG(peripheralBase,(ChannelIdx)) \
  )

/* ----------------------------------------------------------------------------
   -- ReadTimerValueReg
   ---------------------------------------------------------------------------- */

/**
 * Returns the content of the current timer value register.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_ReadTimerValueReg(peripheralBase, ChannelIdx) ( \
    PIT_CVAL_REG(peripheralBase,(ChannelIdx)) \
  )

/* ----------------------------------------------------------------------------
   -- EnableDevice
   ---------------------------------------------------------------------------- */

/**
 * Enables the PIT channel device.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 * @param State Requested state of PIT channel.
 */
#define PIT_PDD_EnableDevice(peripheralBase, ChannelIdx, State) ( \
    PIT_TCTRL_REG(peripheralBase,(ChannelIdx)) = \
     (uint32_t)(( \
      (uint32_t)(( \
       PIT_TCTRL_REG(peripheralBase,(ChannelIdx))) & ( \
       (uint32_t)(~(uint32_t)PIT_TCTRL_TEN_MASK)))) | ( \
      (uint32_t)(State))) \
  )

/* ----------------------------------------------------------------------------
   -- GetEnableDeviceStatus
   ---------------------------------------------------------------------------- */

/**
 * Returns current state of PIT channel device.
 * @param peripheralBase Peripheral base address.
 * @param ChannelIdx PIT channel index.
 */
#define PIT_PDD_GetEnableDeviceStatus(peripheralBase, ChannelIdx) ( \
    (uint32_t)(PIT_TCTRL_REG(peripheralBase,(ChannelIdx)) & PIT_TCTRL_TEN_MASK) \
  )
#endif  /* #if defined(PIT_PDD_H_) */

/* PIT_PDD.h, eof. */
