/** ###################################################################
**     Filename    : mqx_tasks.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : Events
**     Version     : Driver 01.00
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-08-14, 13:12, # CodeGen: 1
**     Abstract    :
**         This is user's event module.
**         Put your event handler code here.
**     Settings    :
**     Contents    :
**         Init_Task - void Init_Task(uint32_t task_init_data);
**         TSS_Trigger - void TSS_Trigger(uint32_t task_init_data);
**
** ###################################################################*/
/* MODULE mqx_tasks */

#include "Cpu.h"
#include "Events.h"
#include "mqx_tasks.h"

/* User includes (#include below this line is not maintained by Processor Expert) */
#include <cstdlib>
#include "Common.h"
#include "MMA845xQ.h"

LDD_TDeviceData *I2C_DeviceData = NULL;
LDD_TDeviceData *PWMTimerRG_DeviceData = NULL;
LDD_TDeviceData *PWMTimerB_DeviceData = NULL;
LDD_TDeviceData *PeriodicTimer = NULL;

volatile bool BlinkFlag = FALSE;
TDataState DataState;



/*
** ===================================================================
**     Event       :  Init_Task (module mqx_tasks)
**
**     Component   :  Task1 [MQXLite_task]
**     Description :
**         MQX task routine. The routine is generated into mqx_tasks.c
**         file.
**     Parameters  :
**         NAME            - DESCRIPTION
**         task_init_data  - 
**     Returns     : Nothing
** ===================================================================
*/
void Init_Task(uint32_t task_init_data)
{
  LDD_TError Error;
  byte Data;
  
  Configure(); /* TSS init */
#if CONSOLE_IO_SUPPORT
  printf("Project description:\n");
  printf("I2C example of communication with external accelerometer.\n");
  printf("PWM is used for dimming the RGB LED in dependence on tilt of the board.\n");
  printf("\n");
#endif
  I2C_DeviceData = I2C_Init(&DataState);
#if CONSOLE_IO_SUPPORT
  printf("Description:\n");
  printf("1) Initialization of MMA8451Q accelerometer... ");
#endif
  Error = !ReadAccRegs(I2C_DeviceData, &DataState, CTRL_REG_1, ACC_REG_SIZE, &Data);
  if (!Error) {
    Data = (ACTIVE_BIT_MASK | F_READ_BIT_MASK); /* Set active mode bit and fast read mode bit */
    Error = !WriteAccRegs(I2C_DeviceData, &DataState, CTRL_REG_1, ACC_REG_SIZE, &Data);
  }
  if (!Error) {
    Data = 0;
    Error = !ReadAccRegs(I2C_DeviceData, &DataState, CTRL_REG_1, ACC_REG_SIZE, &Data);
    if (!Error) {
      if (Data != (ACTIVE_BIT_MASK | F_READ_BIT_MASK)) {
        Error = TRUE;
      }
    }
  }
#if CONSOLE_IO_SUPPORT  
   /* Initialization passed? */
  if (!Error) {
    printf("PASSED.\n");
  } else {
    printf("FAILED.\n");
  }
   
  if (!Error) {
 	  printf("2) Tilt your Freedom Board to change the RGB LED colors.\n");
    printf("3) Swipe the slider to change blink rate.\n");
  }
#endif   
  PWMTimerRG_DeviceData = PWMTimerRG_Init(NULL);
  PWMTimerB_DeviceData = PWMTimerB_Init(NULL);
  PeriodicTimer = BlinkRateCounter_Init(NULL);
  _task_create_at(0, COLORTASK_TASK, 0, ColorTask_task_stack, COLORTASK_TASK_STACK_SIZE);
  _task_create_at(0, TSS_TRIGGER_TASK, 0, TSS_Trigger_task_stack, TSS_TRIGGER_TASK_STACK_SIZE);
}

/*
** ===================================================================
**     Event       :  TSS_Trigger (module mqx_tasks)
**
**     Component   :  Task2 [MQXLite_task]
**     Description :
**         MQX task routine. The routine is generated into mqx_tasks.c
**         file.
**     Parameters  :
**         NAME            - DESCRIPTION
**         task_init_data  - 
**     Returns     : Nothing
** ===================================================================
*/
void TSS_Trigger(uint32_t task_init_data)
{
  while(1)
  {
    TSS_Task();
    _time_delay_ticks(1);
  }
}

/*
** ===================================================================
**     Event       :  ColorTask (module mqx_tasks)
**
**     Component   :  Task3 [MQXLite_task]
**     Description :
**         MQX task routine. The routine is generated into mqx_tasks.c
**         file.
**     Parameters  :
**         NAME            - DESCRIPTION
**         task_init_data  - 
**     Returns     : Nothing
** ===================================================================
*/
void ColorTask(uint32_t task_init_data)
{
  LDD_TError Error;
  signed char Color[3];
  while(1)
  {
    Error = !ReadAccRegs(I2C_DeviceData, &DataState, OUT_X_MSB, 3 * ACC_REG_SIZE, (uint8_t*) Color);  // Read x,y,z acceleration data.
    if (!Error) {
      if (!BlinkFlag) {
        PWMTimerRG_Enable(PWMTimerRG_DeviceData);
        PWMTimerB_Enable(PWMTimerB_DeviceData);
        PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, 0,1000*(1<<(abs(Color[0]/10)))); // x axis - red LED 
        PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, 1, 1000*(1<<(abs(Color[1]/10)))); // y axis - green LED 
        PWMTimerB_SetOffsetTicks(PWMTimerB_DeviceData, 0, 1000*(1<<(abs(Color[2]/10)))); // z axis - blue LED
      }
    }
  _time_delay_ticks(1);
  }
}
/* END mqx_tasks */

/*
** ###################################################################
**
**     This file was created by Processor Expert 0.00.00 [05.02]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
