/** ###################################################################
**     Filename    : Events.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : Events
**     Version     : Driver 01.00
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-08-02, 10:36, # CodeGen: 0
**     Abstract    :
**         This is user's event module.
**         Put your event handler code here.
**     Settings    :
**     Contents    :
**         Cpu_OnNMIINT - void Cpu_OnNMIINT(void);
**
** ###################################################################*/
/* MODULE Events */

#include "Cpu.h"
#include "Events.h"

extern uint8 conv_done;
extern uint8 dma_done;
/* User includes (#include below this line is not maintained by Processor Expert) */

/*
** ===================================================================
**     Event       :  Cpu_OnNMIINT (module Events)
**
**     Component   :  Cpu [MKL25Z128LK4]
**     Description :
**         This event is called when the Non maskable interrupt had
**         occurred. This event is automatically enabled when the <NMI
**         interrrupt> property is set to 'Enabled'.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void Cpu_OnNMIINT(void)
{
  /* Write your code here ... */
}



void LPTMR_IRQHandler(void)
{
// NOTE: The routine should include actions to clear the appropriate
//       interrupt flags.
//
	uint32 temp32;
	LPTMR0_CSR |=  LPTMR_CSR_TCF_MASK;   // write 1 to TCF to clear the LPT timer compare flag
	LPTMR0_CSR |= (LPTMR_CSR_TEN_MASK);
	/*wait for write to complete to  before returning */  
	temp32 = LPTMR0_CSR;
	
	//GPIO1_ToggleFieldBits(GPIO1_DeviceData, LED_BLUE, (GPIO1_TFieldValue)1);
	conv_done = 1;
}

/*
** ===================================================================
**     Event       :  DMAT_ADC_OnComplete (module Events)
**
**     Component   :  DMAT_ADC [DMATransfer_LDD]
**     Description :
**         Called at the end of a DMA transfer. If the Half complete
**         property in initialization section is anabled, this event is
**         also called when current major iteration count reaches the
**         halfway point. See SetEventMask() and GetEventMask() methods.
**         This event is enabled only if Interrupts property in Channel
**         select section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/
void DMAT_ADC_OnComplete(LDD_TUserData *UserDataPtr)
{
	// Clear pending errors or the done bit 
	if (((DMA_DSR_BCR0 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	     | ((DMA_DSR_BCR0 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	     | ((DMA_DSR_BCR0 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	     | ((DMA_DSR_BCR0 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
	{
	  DMA_DSR_BCR0 |= DMA_DSR_BCR_DONE_MASK;
	}
        
        dma_done = 1; // Signal that the DMA transfer is done!
	
        // Reset the BCR!
        DMAT_ADC_SetByteCount(DMAT_ADC_DeviceData, (LDD_DMA_TByteCount)(SAMPLE_SIZE));
                
}

/*
** ===================================================================
**     Event       :  DMAT_ADC_OnError (module Events)
**
**     Component   :  DMAT_ADC [DMATransfer_LDD]
**     Description :
**         Called when error in channel settings is detected. See
**         SetEventMask() and GetEventMask() methods. This event is
**         enabled only if Interrupts property in Channel select
**         section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/
void DMAT_ADC_OnError(LDD_TUserData *UserDataPtr)
{
    
   
    DMAT_ADC_DisableChannel(DMAT_ADC_DeviceData); 
    
     // Clear pending errors or the done bit
    if (((DMA_DSR_BCR0 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	     | ((DMA_DSR_BCR0 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	     | ((DMA_DSR_BCR0 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	     | ((DMA_DSR_BCR0 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
    {
	  DMA_DSR_BCR0 |= DMA_DSR_BCR_DONE_MASK;
          
    }
    // Reset the BCR!
    DMAT_ADC_SetByteCount(DMAT_ADC_DeviceData, (LDD_DMA_TByteCount)(SAMPLE_SIZE));
    
    // Re-enable the channel!
    DMAT_ADC_EnableChannel(DMAT_ADC_DeviceData);
}

/*
** ===================================================================
**     Event       :  DMAT_Mem_OnComplete (module Events)
**
**     Component   :  DMAT_Mem [DMATransfer_LDD]
**     Description :
**         Called at the end of a DMA transfer. If the Half complete
**         property in initialization section is anabled, this event is
**         also called when current major iteration count reaches the
**         halfway point. See SetEventMask() and GetEventMask() methods.
**         This event is enabled only if Interrupts property in Channel
**         select section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/
void DMAT_Mem_OnComplete(LDD_TUserData *UserDataPtr)
{
    // Disable the channel first!
    DMAT_Mem_DisableChannel(DMAT_Mem_DeviceData);
  // Clear pending errors or the done bit 
    if (((DMA_DSR_BCR1 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	| ((DMA_DSR_BCR1 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	| ((DMA_DSR_BCR1 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	| ((DMA_DSR_BCR1 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
    {
    DMA_DSR_BCR1 |= DMA_DSR_BCR_DONE_MASK;
    }
	
    // Reset the BCR!
    DMAT_Mem_SetByteCount(DMAT_Mem_DeviceData, (LDD_DMA_TByteCount)(SAMPLE_SIZE));
    
    // Re-enable the channel!
   DMAT_Mem_EnableChannel(DMAT_Mem_DeviceData);
    
}

/*
** ===================================================================
**     Event       :  DMAT_Mem_OnError (module Events)
**
**     Component   :  DMAT_Mem [DMATransfer_LDD]
**     Description :
**         Called when error in channel settings is detected. See
**         SetEventMask() and GetEventMask() methods. This event is
**         enabled only if Interrupts property in Channel select
**         section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/
void DMAT_Mem_OnError(LDD_TUserData *UserDataPtr)
{
    
 // Disable the channel if there is an error writing to the memory!
    DMAT_Mem_DisableChannel(DMAT_Mem_DeviceData);
}


/////////////////////////////////////////////////////////////////////////////////
// void WriteOutputArray(float Avg, float Der)
//
// Description:  This function accepts two floating point numbers (one 
//   representing the average of the samples and the other representing the 
//   average of the derivative of the samples).  These numbers are split into 
//   two parts (one representing the left side of the decimal, and one on the 
//   right side of the decimal) and then converted to their appropriate base
//   10 representation. These numbers are then masked off and converted to
//   their appropriate ASCII character representation value (by adding 48) and
//   stored in the appropriate location of MyOutputArray for output to the 
//   UART terminal.  
//
//   Parameters:
//   Avg - Floating point number representing the average of the samples
//   Der - Floating point number representing the average of the derivative
//         of the samples
//
//   Variables:
//   
//   numAvg:  Number representing the left-hand side of the decimal of the
//            average value of the samples
//   fracAvg: Number representing the right-hand side of the decimal of the 
//            average value of the samples
//   
//   numDer:  Number representing the left-hand side of the decimal of the 
//            average of the derivative of the samples
//   fracDer: Number representing the right-hand side of the decimal of the 
//            average of the derivative of the samples

void WriteOutputArray(float Avg, float Der)
{
    uint32 numAvg, fracAvg, numDer, fracDer;
    
    
    ///////////////////////////////////////////////////////////////////////////
    // Store the Average values!
    numAvg = Avg;
    
    fracAvg = (Avg - numAvg) * 1000;
    
    MyOutputArray[AVG_START + 4] = ((numAvg % 0xA) + 48);
    
    numAvg = numAvg / 0xA;
    
    MyOutputArray[AVG_START + 3] = ((numAvg % 0xA) + 48);
    
    numAvg = numAvg / 0xA;
    
    MyOutputArray[AVG_START + 2] = ((numAvg % 0xA) + 48);
    
    numAvg = numAvg / 0xA;
    
    MyOutputArray[AVG_START + 1] = ((numAvg % 0xA) + 48);
    
    numAvg = numAvg / 0xA;
    
    MyOutputArray[AVG_START + 0] = ((numAvg % 0xA) + 48);
    
    MyOutputArray[AVG_START + 8] = ((fracAvg % 0xA) + 48);
    
    fracAvg = fracAvg / 0xA;
    
    MyOutputArray[AVG_START + 7] = ((fracAvg % 0xA) + 48);
    
    fracAvg = fracAvg / 0xA;
    
    MyOutputArray[AVG_START + 6] = ((fracAvg % 0xA) + 48);
    
    
    ///////////////////////////////////////////////////////////////////////////
    // Store the Average Derivative values!
    numDer = Der;
    
    fracDer = (Der - numDer) * 1000;
    
    MyOutputArray[DER_START + 4] = ((numDer % 0xA) + 48);
    
    numDer = numDer / 0xA;
    
    MyOutputArray[DER_START + 3] = ((numDer % 0xA) + 48);
    
    numDer = numDer / 0xA;
    
    MyOutputArray[DER_START + 2] = ((numDer % 0xA) + 48);
    
    numDer = numDer / 0xA;
    
    MyOutputArray[DER_START + 1] = ((numDer % 0xA) + 48);
    
    numDer = numDer / 0xA;
    
    MyOutputArray[DER_START + 0] = ((numDer % 0xA) + 48);
    
    MyOutputArray[DER_START + 8] = ((fracDer % 0xA) + 48);
    
    fracDer = fracDer / 0xA;
    
    MyOutputArray[DER_START + 7] = ((fracDer % 0xA) + 48);
    
    fracDer = fracDer / 0xA;
    
    MyOutputArray[DER_START + 6] = ((fracDer % 0xA) + 48);
}

/***************************************************************/
/* VLPS mode entry routine. Puts the processor into VLPS mode 
 * directly from run or VLPR modes. 
 *
 * Mode transitions:
 * RUN  -> VLPS
 * VLPR -> VLPS
 *
 * Note, when VLPS is entered directly from RUN or VLPR mode, 
 * exit to VLPR is disabled by hardware and the system will
 * always exit back to RUN.
 *
 * Parameters:  
 * none
 */
 /****************************************************************/

void enter_vlps(void)
{
   uint8 temp8;
  // Setup to move to VLPS mode here.  The code should be configured to return to VLPS after ISR
  temp8 = SMC_PMCTRL;
  temp8 &= ~SMC_PMCTRL_STOPM_MASK;
  temp8 |= SMC_PMCTRL_STOPM(2);
  SMC_PMCTRL = temp8;
   
  // Execute dummy read
  temp8 = SMC_PMCTRL;
        
  // Set Deep Sleep bit
  SCB_SCR |= SCB_SCR_SLEEPDEEP_MASK;
   
  // Execute wait for interrupt command
  __wfi;
}

/********************************************************************/
/* WAIT mode entry routine. Puts the processor into wait mode.
 * In this mode the core clock is disabled (no code executing), but 
 * bus clocks are enabled (peripheral modules are operational). 
 *
 * Mode transitions:
 * RUN -> WAIT
 * VLPR -> VLPW
 *
 * This function can be used to enter normal wait mode or VLPW
 * mode. If you are executing in normal run mode when calling this
 * function, then you will enter normal wait mode. If you are in VLPR
 * mode when calling this function, then you will enter VLPW mode instead.
 *
 * NOTE: Some modules include a programmable option to disable them in 
 * wait mode. If those modules are programmed to disable in wait mode, 
 * they will not be able to generate interrupts to wake up the core.
 *
 * WAIT mode is exited using any enabled interrupt or RESET, so no
 * exit_wait routine is needed. 
 * 
 * 
 * Parameters:
 * none
 */

void enter_wait(void)
{
    SCB_SCR &= ~SCB_SCR_SLEEPDEEP_MASK;
    __wfi;
}

void enable_systick(void)
{
  SYST_RVR = 0x00002000; //SysTick Reload Value Register
  SYST_CVR = 0x00000000;
  SYST_CSR = SysTick_CSR_ENABLE_MASK | 
             SysTick_CSR_TICKINT_MASK |
             SysTick_CSR_CLKSOURCE_MASK;
}

/* END Events */

/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.02]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
