/** ###################################################################
**     Filename    : Events.h
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : Events
**     Version     : Driver 01.00
**     Compiler    : IAR ARM C Compiler
**     Date/Time   : 2012-08-28, 17:30, # CodeGen: 81
**     Abstract    :
**         This is user's event module.
**         Put your event handler code here.
**     Settings    :
**     Contents    :
**         DMAT_Mem_OnComplete - void DMAT_Mem_OnComplete(LDD_TUserData *UserDataPtr);
**         DMAT_Mem_OnError    - void DMAT_Mem_OnError(LDD_TUserData *UserDataPtr);
**         DMAT_ADC_OnComplete - void DMAT_ADC_OnComplete(LDD_TUserData *UserDataPtr);
**         DMAT_ADC_OnError    - void DMAT_ADC_OnError(LDD_TUserData *UserDataPtr);
**         Cpu_OnNMIINT        - void Cpu_OnNMIINT(void);
**
** ###################################################################*/

#ifndef __Events_H
#define __Events_H
/* MODULE Events */

#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"
#include "ADC0.h"
#include "GPIO1.h"
#include "LPTmr1.h"
#include "GPIO2_VDD.h"
#include "GPIO3_VSS.h"
#include "DMAT_ADC.h"
#include "DMA1.h"
#include "TPM0.h"
#include "DMAT_Mem.h"
#include "DMAT_UART_OUT.h"
#include "PE_LDD.h"


#define OUTPUT_ARRAY_SIZE     80
#define AVG_START             40 + 7
#define DER_START             60 + 7
#define SAMPLE_SIZE           0x80

extern uint16 MyStaticArray[SAMPLE_SIZE/2];
extern char MyOutputArray[OUTPUT_ARRAY_SIZE];
void enable_systick(void);
void WriteOutputArray(float Avg, float Der);
void enter_vlps(void);
void enter_wait(void);

void DMAT_Mem_OnComplete(LDD_TUserData *UserDataPtr);
/*
** ===================================================================
**     Event       :  DMAT_Mem_OnComplete (module Events)
**
**     Component   :  DMAT_Mem [DMATransfer_LDD]
**     Description :
**         Called at the end of a DMA transfer. If the Half complete
**         property in initialization section is anabled, this event is
**         also called when current major iteration count reaches the
**         halfway point. See SetEventMask() and GetEventMask() methods.
**         This event is enabled only if Interrupts property in Channel
**         select section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/

void DMAT_Mem_OnError(LDD_TUserData *UserDataPtr);
/*
** ===================================================================
**     Event       :  DMAT_Mem_OnError (module Events)
**
**     Component   :  DMAT_Mem [DMATransfer_LDD]
**     Description :
**         Called when error in channel settings is detected. See
**         SetEventMask() and GetEventMask() methods. This event is
**         enabled only if Interrupts property in Channel select
**         section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/

void DMAT_ADC_OnComplete(LDD_TUserData *UserDataPtr);
/*
** ===================================================================
**     Event       :  DMAT_ADC_OnComplete (module Events)
**
**     Component   :  DMAT_ADC [DMATransfer_LDD]
**     Description :
**         Called at the end of a DMA transfer. If the Half complete
**         property in initialization section is anabled, this event is
**         also called when current major iteration count reaches the
**         halfway point. See SetEventMask() and GetEventMask() methods.
**         This event is enabled only if Interrupts property in Channel
**         select section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/

void DMAT_ADC_OnError(LDD_TUserData *UserDataPtr);
/*
** ===================================================================
**     Event       :  DMAT_ADC_OnError (module Events)
**
**     Component   :  DMAT_ADC [DMATransfer_LDD]
**     Description :
**         Called when error in channel settings is detected. See
**         SetEventMask() and GetEventMask() methods. This event is
**         enabled only if Interrupts property in Channel select
**         section is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/

void Cpu_OnNMIINT(void);
/*
** ===================================================================
**     Event       :  Cpu_OnNMIINT (module Events)
**
**     Component   :  Cpu [MKL25Z128LK4]
**     Description :
**         This event is called when the Non maskable interrupt had
**         occurred. This event is automatically enabled when the <NMI
**         interrrupt> property is set to 'Enabled'.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/


/* END Events */
#endif /* __Events_H*/

/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.03]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
