/** ###################################################################
**     Filename    : ProcessorExpert.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Version     : Driver 01.01
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-08-02, 10:36, # CodeGen: 0
**     Abstract    :
**         Main module.
**         This module contains user's application code.
**     Settings    :
**     Contents    :
**         No public methods
**
** ###################################################################*/
/* MODULE ProcessorExpert */


/* Including needed modules to compile this module/procedure */
#include "Cpu.h"
#include "Events.h"
#include "ADC0.h"
#include "GPIO1.h"
#include "TPM0.h"
#include "DMAT_Mem.h"
#include "DMAT_UART_OUT.h"
#include "LPTmr1.h"
#include "GPIO2_VDD.h"
#include "GPIO3_VSS.h"
#include "DMAT_ADC.h"
#include "DMA1.h"
/* Including shared modules, which are used for whole project */
#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"

/* User includes (#include below this line is not maintained by Processor Expert) */
#include <stdlib.h>
#include <stdio.h>
#include <math.h>

/** Global Variables **/
uint16 adc_val = 0;
uint8  conv_done = 0;
uint8  dma_done = 0;

#pragma data_alignment = SAMPLE_SIZE
__root uint16 MyStaticArray[SAMPLE_SIZE/2]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};

char MyOutputArray[OUTPUT_ARRAY_SIZE] = {
    'F','r','e','e','s','c','a','l','e',' ','T','P','M',' ','D','e','m','o','\n','\r',
    '-','-','-','-','-','-','-','-','-','-','-','-','-','-','-','-','-','-','\n','\r',
    'A','v','g',' ','-','>',' ',' ','N','U','L','L','.',' ',' ',' ',' ',' ',' ',' ','D','e','r',' ','-','>',' ',' ','N','U','L','L','.',' ',' ',' ',' ',' ',' ','\r'};


/////////////////////////////////////////////////////////////////////////////////
// Program Constant Definitions
#define TERMINAL_BAUD        19200
#define UART_IRCLK_SRC       3
#define DATA_OFFSET_ADDR     &MyOutputArray + 40
#define LINE_SIZE            40



int main(void)
{
  /* Write your local variable definition here */
  uint8 i;
  uint32 myadcAvg = 0;
  float adcAvgFlt = 0;
  float AvgDerTemp = 0, AvgDer = 0;
  uint32 uart0_clk_khz = 0;
  LDD_TError StartErr = 0;

  /*** Processor Expert internal initialization. DON'T REMOVE THIS CODE!!! ***/
  PE_low_level_init();
  /*** End of Processor Expert internal initialization.                    ***/
  
  ////////////////////////////////////////////////////////////////////////////////
  // Configure UART0 
  
  // Configure UART pins
  // Enable the UART_TXD function on PTA1 
  PORTA_PCR1 = PORT_PCR_MUX(0x2);
          
  // Enable the UART_TXD function on PTA2 
  PORTA_PCR2 = PORT_PCR_MUX(0x2);
  
  // Configure UART0 clock source
  SIM_SOPT2 |= SIM_SOPT2_UART0SRC(UART_IRCLK_SRC);
  uart0_clk_khz = 1000;  // UART0 Clk in kHz = 1000 kHz if using the IRCLK at 1MHz
  
  // Initialize UART Module
  uart0_init (UART0_BASE_PTR, uart0_clk_khz, TERMINAL_BAUD);
 
  /*
  // A Sample group MUST be created or selected the ADC will not get samples!! */
  StartErr = ADC0_SelectSampleGroup(ADC0_DeviceData, (uint8_t) 0);
  
  // Toggle the status LED as the calibration is complete.  
   GPIO1_ToggleFieldBits(GPIO1_DeviceData, LED_BLUE, (GPIO1_TFieldValue)1);
   
  // Allocate and enable DMA channel for ADC transfers
   StartErr = DMAT_ADC_AllocateChannel(DMAT_ADC_DeviceData);
   
   StartErr = DMAT_ADC_EnableChannel(DMAT_ADC_DeviceData);
  
   // Allocate and enable DMA channel for Linked transfers to memory
   StartErr = DMAT_Mem_AllocateChannel(DMAT_Mem_DeviceData);
   
   StartErr = DMAT_Mem_EnableChannel(DMAT_Mem_DeviceData);
   
   // Allocate DMA channel for UART0 Transfers
   StartErr = DMAT_UART_OUT_AllocateChannel(DMAT_UART_OUT_DeviceData);
   
   // Start Measurements
   StartErr = ADC0_StartLoopTriggeredMeasurement(ADC0_DeviceData);
   
   ADC0_SC2 |= ADC_SC2_DMAEN_MASK;
   // Enable Global Interrupts
   Cpu_EnableInt();
   // Enable the Timer
   LPTMR0_CSR |= LPTMR_CSR_TEN_MASK;                   // Use this line if using the Init module
   
   // Enable the UART DMA Channel
   StartErr = DMAT_UART_OUT_EnableChannel(DMAT_UART_OUT_DeviceData);
   
   // Wait for UART DMA transaction to complete
   while ((DMA_DSR_BCR2 & DMA_DSR_BCR_DONE_MASK) != DMA_DSR_BCR_DONE_MASK);
   
    while(1)
    {
        enter_vlps();
         
        while(dma_done == 0);
        
        dma_done = 0;  // Signal that we are waiting on DMA again!
        
        // Disable the LPTMR
        LPTMR0_CSR &= ~LPTMR_CSR_TEN_MASK;                   // Use this line if using the Init module
        
        // Ensure that the UART DMA transfers are done    
        while ((DMA_DSR_BCR2 & DMA_DSR_BCR_DONE_MASK) != DMA_DSR_BCR_DONE_MASK);
        
        // Disable UART DMA Channel
        StartErr = DMAT_UART_OUT_DisableChannel(DMAT_UART_OUT_DeviceData);
            
        // Enter CPO mode  
        // Set the CPO mask
        MCM_CPO |= MCM_CPO_CPOREQ_MASK;
        
        // Wait for CPO acknowledgement
        while(!(MCM_CPO & MCM_CPO_CPOACK_MASK));
        
        // Initialize the ADC average variable
        myadcAvg = 0;
        
        // Reset the Average Derivative variable.  
        AvgDer = 0;
        
        //Calculate average value of the ADC measurements and the average rate of change
        //   (the average derivative)
         for (i = 0; i < SAMPLE_SIZE/2; i++)
         {
             myadcAvg = myadcAvg + MyStaticArray[i];
             
             if (i == 0)
                 AvgDerTemp = MyStaticArray[i];
             else
             {
                 AvgDerTemp = MyStaticArray[i - 1];
                 AvgDerTemp = MyStaticArray[i] - AvgDerTemp;
                 AvgDer = AvgDer + AvgDerTemp;
             }
	 }
         
         // Find Floating point value
         adcAvgFlt = myadcAvg / (float)(SAMPLE_SIZE/2);
         AvgDer = AvgDer / (float)(SAMPLE_SIZE/2);
         
         // Update the output array with the new values
         WriteOutputArray(adcAvgFlt, AvgDer);
         
         // Exit CPO mode
         MCM_CPO &= ~MCM_CPO_CPOREQ_MASK;
         while (MCM_CPO & MCM_CPO_CPOACK_MASK);
         
            
         // Clear Error or Done Bit
         if (((DMA_DSR_BCR2 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
         {
             DMA_DSR_BCR2 |= DMA_DSR_BCR_DONE_MASK;
         }
         
         // Do this twice just in case of an error AND done
         if (((DMA_DSR_BCR2 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
         {
             DMA_DSR_BCR2 |= DMA_DSR_BCR_DONE_MASK;
         }
         
         // Reset the UART DMA
         StartErr = DMAT_UART_OUT_SetSourceAddress(DMAT_UART_OUT_DeviceData, (uint32_t)DATA_OFFSET_ADDR);
         StartErr = DMAT_UART_OUT_SetByteCount(DMAT_UART_OUT_DeviceData, (LDD_DMA_TByteCount)(LINE_SIZE));
         
         StartErr = DMAT_UART_OUT_EnableChannel(DMAT_UART_OUT_DeviceData);
            
         // Re-enable the LPTMR
         LPTMR0_CSR |= LPTMR_CSR_TEN_MASK;                   // Use this line if using the Init module
    }

  /*** Don't write any code pass this line, or it will be deleted during code generation. ***/
  /*** RTOS startup code. Macro PEX_RTOS_START is defined by the RTOS component. DON'T MODIFY THIS CODE!!! ***/
  #ifdef PEX_RTOS_START
    PEX_RTOS_START();                  /* Startup of the selected RTOS. Macro is defined by the RTOS component. */
  #endif
  /*** End of RTOS startup code.  ***/
  /*** Processor Expert end of main routine. DON'T MODIFY THIS CODE!!! ***/
  for(;;){}
  /*** Processor Expert end of main routine. DON'T WRITE CODE BELOW!!! ***/
  return 0;
} /*** End of main routine. DO NOT MODIFY THIS TEXT!!! ***/

/* END ProcessorExpert */
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.02]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
