/** ###################################################################
**     Filename    : ProcessorExpert.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Version     : Driver 01.01
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-08-08, 16:59, # CodeGen: 0
**     Abstract    :
**         Main module.
**         This module contains user's application code.
**     Settings    :
**     Contents    :
**         No public methods
**
** ###################################################################*/
/* MODULE ProcessorExpert */


/* Including needed modules to compile this module/procedure */
#include "Cpu.h"
#include "Events.h"
#include "Blue_LED.h"
#include "Green_LED.h"
#include "Red_LED.h"
#include "CsIO1.h"
#include "IO1.h"
#include "DA1.h"
#include "TU2.h"
/* Including shared modules, which are used for whole project */
#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"

/* User includes (#include below this line is not maintained by Processor Expert) */
#include "stdio.h"

/* Global Variables */
volatile bool DataReceivedFlg = FALSE;
TU2_TValueType pTicks;

uint16 gu16WaveformBuffer[33] = {0};
uint16 gu16SineWaveBuffer[]  =  {2047,2446,2830,3184,3494,3749,3938,4055,4094,4055,3938,3749,3494,3184,2830,2446,2047,
                                 1648,1264,910,600,345,156,39,0,39,156,345,600,910,1264,1648,2047,0xFFF};

uint16 *pWaveform, *pGenerateData;

int main(void)
{
  /* Write your local variable definition here */
  char selection,i,j;

  /*** Processor Expert internal initialization. DON'T REMOVE THIS CODE!!! ***/
  PE_low_level_init();
  /*** End of Processor Expert internal initialization.                    ***/

  /* Write your code here */
  pWaveform = (uint16 *)gu16SineWaveBuffer; 
  /* BLUE LED ON */ 
  Blue_LED_ClrVal(Blue_LED_DeviceData);    
  
  for(;;)
  {
    
    printf("\n\n*----------------------------------------\n");
    printf("*  Select Waveform                         \n");
    printf("*----------------------------------------\n\n");
    printf("1 SquareWave       \n");
    printf("2 SawtoothWave     \n");
    printf("3 TriangleWave     \n");
    printf("4 SineWave         \n");
    printf("5 Increase Freq.   \n"); 
    printf("6 Decrease Freq.   \n"); 
    
    // Due to an issue with ProcessorExpert and the CodeWarrior standard getchar/putchar 
    //    routines, use uart_getchar and uart_putchar to receive and send single characters 
    //    (respectively).  
    selection = uart_getchar(TERM_PORT_NUM);
    uart_putchar(TERM_PORT_NUM, selection);   
    
    if (selection <='0'  || selection >='9') 
      selection=0;
       
    switch(selection)
   {

     case '1': // Case SquareWave 
       pWaveform = (uint16 *)gu16SineWaveBuffer; //While SquareWave is generated take SineWave 
       pGenerateData = (uint16 *)gu16WaveformBuffer;         
       for(i=0;i<16;i++)  //Generate SquareWave
         *(pGenerateData+i)=0;
       for(i=16;i<32;i++)
         *(pGenerateData+i)=4094;
       *(pGenerateData+32)=0xFFF;  
       pWaveform = (uint16 *)gu16WaveformBuffer;
      /* BLUE LED ON */ 
       Blue_LED_ClrVal(Blue_LED_DeviceData);
       Green_LED_SetVal(Green_LED_DeviceData);
       Red_LED_SetVal(Red_LED_DeviceData);      
       break;
     case '2': // Case SawtoothWave   
       pWaveform = (uint16 *)gu16SineWaveBuffer;  //While SawtoothWave is generated take SineWave 
       pGenerateData = (uint16 *)gu16WaveformBuffer;       
       for(i=0;i<32;i++) // Generate SawtoothWave
         *(pGenerateData+i)=i*128;
       *(pGenerateData+32)=0xFFF; 
       pWaveform = (uint16 *)gu16WaveformBuffer;
       /* GREEN LED ON */        
       Blue_LED_SetVal(Blue_LED_DeviceData);
       Green_LED_ClrVal(Green_LED_DeviceData);
       Red_LED_SetVal(Red_LED_DeviceData);
       break;
     case '3': // Case TriangleWave 
       pWaveform = (uint16 *)gu16SineWaveBuffer;  //While TriangleWave is generated take SineWave
       pGenerateData = (uint16 *)gu16WaveformBuffer; 
       j=15;
       for(i=0;i<16;i++)  // Generate TriangleWave
         *(pGenerateData+i)=i*256;
       *(pGenerateData+16)=4094;
       for(i=17;i<32;i++)
         *(pGenerateData+i)=(j--)*256;
       *(pGenerateData+32)=0xFFF;
       pWaveform = (uint16 *)gu16WaveformBuffer;  
       /* RED LED ON */        
       Blue_LED_SetVal(Blue_LED_DeviceData);
       Green_LED_SetVal(Green_LED_DeviceData);
       Red_LED_ClrVal(Red_LED_DeviceData);     
       break;
     case '4': // Case SineWave  
       pWaveform = (uint16 *)gu16SineWaveBuffer; 
       /* YELLOW LED ON */        
       Blue_LED_SetVal(Blue_LED_DeviceData);
       Green_LED_ClrVal(Green_LED_DeviceData);
       Red_LED_ClrVal(Red_LED_DeviceData);   
       break;
     case '5': 
       TU2_GetPeriodTicks(TU2_DeviceData, &pTicks);
       pTicks/=2;
       if(pTicks<94) 
         pTicks=94;
       TU2_SetPeriodTicks(TU2_DeviceData, pTicks);
       printf("\nticks=  %i \n",pTicks);
       break;
     case '6': 
       TU2_GetPeriodTicks(TU2_DeviceData, &pTicks);
       pTicks*=2;
       if(pTicks>12000) 
         pTicks=12000;
       TU2_SetPeriodTicks(TU2_DeviceData, pTicks);
       printf("\nticks=  %i \n",pTicks);
       break;
     
     default:  // Invalid choice
       /* CYAN LED ON */
       Blue_LED_ClrVal(Blue_LED_DeviceData);
       Green_LED_ClrVal(Green_LED_DeviceData);
       Red_LED_SetVal(Red_LED_DeviceData);
       printf("\n\r Invalid choice\n");
    }	  

  }
   

  /*** Don't write any code pass this line, or it will be deleted during code generation. ***/
  /*** RTOS startup code. Macro PEX_RTOS_START is defined by the RTOS component. DON'T MODIFY THIS CODE!!! ***/
  #ifdef PEX_RTOS_START
    PEX_RTOS_START();                  /* Startup of the selected RTOS. Macro is defined by the RTOS component. */
  #endif
  /*** End of RTOS startup code.  ***/
  /*** Processor Expert end of main routine. DON'T MODIFY THIS CODE!!! ***/
  for(;;){}
  /*** Processor Expert end of main routine. DON'T WRITE CODE BELOW!!! ***/
  return 0;
} /*** End of main routine. DO NOT MODIFY THIS TEXT!!! ***/

/* END ProcessorExpert */
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.02]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/


