/** ###################################################################
**     Filename    : ProcessorExpert.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Version     : Driver 01.01
**     Compiler    : ARM C/C++ Compiler
**     Date/Time   : 2012-08-17, 00:56, # CodeGen: 0
**     Abstract    :
**         Main module.
**         This module contains user's application code.
**     Settings    :
**     Contents    :
**         No public methods
**
** ###################################################################*/
/* MODULE ProcessorExpert */


/* Including needed modules to compile this module/procedure */
#include "MKL25Z_MCU.h"
#include "Events.h"
#include "PWMTimerRG.h"
#include "PWMTimerB.h"
#include "PeriodicInterrupt.h"
/* Including shared modules, which are used for whole project */
#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"

/* User includes (#include below this line is not maintained by Processor Expert) */
int MaxTimerPulseOffset  =   (1 << PWMTimerRG_COUNTER_WIDTH) - 1;
int MaxPercent          =    40; /* max pulse width percentage */
#define MaxPulseOffset          (int)((float)MaxTimerPulseOffset*((float)MaxPercent/(100)))
int FadeTime            =    1; /* seconds */
int ServiceInterval =         25; /* ms, determined by PeriodicInterrupt */

#define NumServices             (FadeTime*1000)/ServiceInterval
#define PulseIncrement          MaxPulseOffset/NumServices  

volatile bool PeriodicEvent = FALSE;
volatile bool FadeIn = TRUE;

LDD_TDeviceData *PWMTimerRG_DeviceData, *PWMTimerB_DeviceData;
LDD_TDeviceData *PeriodicInterrupt_DeviceData;

const int RedChannel = 0;
const int GreenChannel = 1;
const int BlueChannel = 0;

enum LED {Red = 0, Green, Blue, Yellow, Cyan, Magenta, END};

/******************************************************************************/
int main(void)
{
	LDD_TError Error;
	int PulseOffset = 0;
	int events = 0;
	enum LED led = Red;

	/*** Processor Expert internal initialization. DON'T REMOVE THIS CODE!!! ***/
	PE_low_level_init();
	/*** End of Processor Expert internal initialization.                    ***/

	/* Intialize the timers */
	PWMTimerRG_DeviceData = PWMTimerRG_Init(NULL);
	PWMTimerB_DeviceData = PWMTimerB_Init(NULL);
	PeriodicInterrupt_DeviceData = PeriodicInterrupt_Init(NULL);

	/* Set initial compare value */
	PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, PulseOffset);
	PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, PulseOffset);
	PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, PulseOffset);

	/* Turn on the timers */
	Error = PWMTimerRG_Enable(PWMTimerRG_DeviceData);
	if (Error != ERR_OK)
		PE_DEBUGHALT();

 	Error = PWMTimerB_Enable(PWMTimerB_DeviceData);
 	if (Error != ERR_OK)
 		PE_DEBUGHALT();

	Error = PeriodicInterrupt_Enable(PeriodicInterrupt_DeviceData);
	if (Error != ERR_OK)
		PE_DEBUGHALT();

	while (1)
	{
		if (PeriodicEvent) {
			PeriodicEvent = FALSE;
			events++;

			if (FadeIn)
				PulseOffset += PulseIncrement;
			else
				PulseOffset -= PulseIncrement;

			/* Update the timers */
			if (led == Red) {
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, PulseOffset);
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, 0);
				PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, 0);
			}
			else if (led == Green) {
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, 0);
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, PulseOffset);
				PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, 0);
			}
			else if (led == Blue) {
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, 0);
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, 0);
				PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, PulseOffset);
			}
			else if (led == Yellow) {
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, PulseOffset);
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, PulseOffset);
				PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, 0);
			}
			else if (led == Cyan) {
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, 0);
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, PulseOffset);
				PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, PulseOffset);
			}
			else if (led == Magenta) {
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, RedChannel, PulseOffset);
				PWMTimerRG_SetOffsetTicks(PWMTimerRG_DeviceData, GreenChannel, 0);
				PWMTimerB_SetOffsetTicks(PWMTimerRG_DeviceData, BlueChannel, PulseOffset);
			}

			if (events == NumServices) {
				events = 0;
				FadeIn = !FadeIn;
				if (FadeIn) {
					led++;
					if (led == END) {
						led = Red;
					}
				}
			}
		}
	}

	/*** Don't write any code pass this line, or it will be deleted during code generation. ***/
  /*** RTOS startup code. Macro PEX_RTOS_START is defined by the RTOS component. DON'T MODIFY THIS CODE!!! ***/
  #ifdef PEX_RTOS_START
    PEX_RTOS_START();                  /* Startup of the selected RTOS. Macro is defined by the RTOS component. */
  #endif
  /*** End of RTOS startup code.  ***/
  /*** Processor Expert end of main routine. DON'T MODIFY THIS CODE!!! ***/
  for(;;){}
  /*** Processor Expert end of main routine. DON'T WRITE CODE BELOW!!! ***/
	return 0;
} /*** End of main routine. DO NOT MODIFY THIS TEXT!!! ***/

/* END ProcessorExpert */
/*
 ** ###################################################################
 **
 **     This file was created by Processor Expert 10.0 [05.03]
 **     for the Freescale Kinetis series of microcontrollers.
 **
 ** ###################################################################
 */
